#
# spec file for package gradle
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gradle
Version:        4.7.0
Release:        1.1
Summary:        A powerful build system for the JVM
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://www.gradle.org
Source0:        %{name}-%{version}.tar.gz
# https://services.gradle.org/versions/all
Source1:        all-released-versions.json
# Disable tests which demand gradle cache in user's home
Patch1:         0001-Search-system-jar.patch
Patch2:         0002-Fix-checkstyle-error.patch
Patch3:         0003-make-groovy-dependency-explicit-in-performance-compi.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gradle-kit == %{version}
BuildRequires:  java-devel = 1.8.0
BuildRequires:  procps
BuildRequires:  unzip
BuildArch:      noarch
Requires:       java-headless = 1.8.0
#Requires:       libnative-platform0

%description
Gradle is a build tool with a focus on build automation and support
for multi-language development. If you are building, testing,
publishing, and deploying software on any platform, Gradle offers a
flexible model that can support the entire development lifecycle from
compiling and packaging code to publishing web sites. Gradle has been
designed to support build automation across multiple languages and
platforms including Java, Scala, Android, C/C++, and Groovy, and is
closely integrated with development tools and continuous integration
servers including Eclipse, IntelliJ, and Jenkins.

For more information about Gradle, please visit: http://gradle.org

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

if [ -d %{_datadir}/tetra/gradle ]; then
  rm -rf /tmp/gradle* /tmp/apache*
  cp -Rf %{_datadir}/tetra/gradle* /tmp
  cp -Rf %{_datadir}/tetra/apache* /tmp
else
  cp -Rf %{_datadir}/tetra ../kit
fi
  
%build

# from debian:rules
#mkdir --parents buildSrc/src/main/java

export GRADLE_USER_HOME=/tmp/gradle
export BUILD_VCS_NUMBER=%{version}
export M2_HOME=`pwd`/../kit/m2
export GRADLE_OPTS="-Xmx1024m"
export LANG=en_US.UTF-8
mkdir build
cp %{S:1} build
./gradlew \
  --gradle-user-home $GRADLE_USER_HOME \
  --project-cache-dir /tmp/gradle-project \
  --stacktrace \
  -x :docs:userguidePdf \
  -Dfile.encoding=UTF-8 \
  --project-prop finalRelease=true \
  --offline \
  --no-daemon \
  --no-parallel \
  assemble

%install
export GRADLE_USER_HOME=/tmp/gradle
export BUILD_VCS_NUMBER=%{version}
export NO_BRP_CHECK_BYTECODE_VERSION=true

./gradlew \
  --gradle-user-home $GRADLE_USER_HOME \
  --project-cache-dir /tmp/gradle-project \
  --project-prop finalRelease=true \
  --offline \
  --no-daemon \
  --no-parallel \
  --project-prop gradle_installPath=%{buildroot}%{_datadir}/%{name} \
  install

chmod  644 %{buildroot}%{_datadir}/%{name}/lib/*.jar
chmod  644 %{buildroot}%{_datadir}/%{name}/lib/plugins/*.jar

mkdir %{buildroot}%{_bindir}
ln -s %{_datadir}/%{name}/bin/gradle %{buildroot}%{_bindir}
rm -f %{buildroot}%{_datadir}/%{name}/bin/gradle.bat

%files
%defattr(-,root,root)
%dir %{_datadir}/%{name}
%{_datadir}/%{name}
%{_bindir}/*

%changelog
* Tue May 29 2018 kkaempf@suse.com
- Update to 4.7.0
  - Incremental annotation processing
  - JDK 10 support
  - Grouped non-interactive console logs
  - Failed tests are re-run first for quicker feedback
  For more details see https://docs.gradle.org/4.7/release-notes.html
- drop 0001-Build-patch.patch
- rename
  0003-Search-system-jar.patch to 0001-Search-system-jar.patch
  0005-Fix-checkstyle-error.patch to 0002-Fix-checkstyle-error.patch
* Sun Apr  1 2018 kkaempf@suse.com
- Update to 4.6.0
  * built-in support for JUnit Platform and the JUnit
    Jupiter/Vintage Engine, also known as JUnit 5 support.
- Update to 4.5.0
  * build cache improvements
- removed patches
  - 0002-Disable-code-quality.patch
  - 0004-Relax-warnings.patch
  - 0006-drop-fonts.patch
* Thu Dec 28 2017 kkaempf@suse.com
- Update to 4.4.1
  * Visual Studio 2017 is now supported.
  * The eclipse plugin now provides separate output folders.
  See https://github.com/gradle/gradle/releases/tag/v4.4.0
  and https://github.com/gradle/gradle/releases/tag/v4.4.1
  for full changelog
* Wed Nov 15 2017 kkaempf@suse.com
- Update to 4.3.1
  Major upgrade
  See https://github.com/gradle/gradle/releases/tag/v4.3.1
* Thu Feb 23 2017 kkaempf@suse.com
- Update to 3.4.1
  Performance improvements
  See https://docs.gradle.org/3.4.1/release-notes.html
  new patches
  - 0006-drop-fonts.patch
  renamed patches
  - 0009-Fix-checkstyle-error.patch to 0005-Fix-checkstyle-error.patch
  - 0008-Relax-warnings.patch to 0004-Relax-warnings.patch
  - 0005-Search-system-jar.patch to 0003-Search-system-jar.patch
  - 0004-Disable-code-quality.patch to 0002-Disable-code-quality.patch
  dropped patches
  - 0007-declare-use-of-jcommander-properly.patch
  - 0006-Disable-AWS.patch
  - 0003-fix-build-of-documentation.patch
  - 0002-fix-classpath-annotation.patch
* Wed Dec 28 2016 kkaempf@suse.com
- Update to 3.2.1
  * bugfix release
  * see https://github.com/gradle/gradle/releases/tag/v3.2.1
